====================================
Pegasus for Single Cell Analysis
====================================

|PyPI|

.. |PyPI| image:: https://img.shields.io/pypi/v/pegasuspy.svg
   :target: https://pypi.org/project/pegasuspy


Pegasus is a tool for analyzing transcriptomes of millions of single cells. It is a command line tool, a python package and a base for Cloud-based analysis workflows.

`Read documentation <http://pegasus.readthedocs.io>`__
